@@ -76,6 +76,7 @@ from .callbacks import (
     on_mcp_disconnect,
     on_message,
     on_settings_update,
+    on_shared_thread_view,
     on_stop,
     on_window_message,
     password_auth_callback,
@@ -121,6 +122,7 @@ __getattr__ = make_module_getattr(
         "instrument_openai": "chainlit.openai",
         "instrument_mistralai": "chainlit.mistralai",
         "SemanticKernelFilter": "chainlit.semantic_kernel",
+        "server": "chainlit.server",
     }
 )
 
@@ -189,6 +191,7 @@ __all__ = [
     "on_mcp_disconnect",
     "on_message",
     "on_settings_update",
+    "on_shared_thread_view",
     "on_stop",
     "on_window_message",
     "password_auth_callback",
