@@ -1,7 +1,4 @@
-import asyncio
-import atexit
 import json
-import signal
 import uuid
 from datetime import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
@@ -52,11 +49,6 @@ class ChainlitDataLayer(BaseDataLayer):
         self.storage_client = storage_client
         self.show_logger = show_logger
 
-        # Register cleanup handlers for application termination
-        atexit.register(self._sync_cleanup)
-        for sig in (signal.SIGINT, signal.SIGTERM):
-            signal.signal(sig, self._signal_handler)
-
     async def connect(self):
         if not self.pool:
             self.pool = await asyncpg.create_pool(self.database_url)
@@ -86,14 +78,13 @@ class ChainlitDataLayer(BaseDataLayer):
             asyncpg.exceptions.InterfaceError,
         ) as e:
             # Handle connection issues by cleaning up and rethrowing
-            logger.error(f"Connection error: {e!s}, cleaning up pool")
+            logger.error(f"Connection error: {e!s}")
             await self.cleanup()
-            self.pool = None
             raise
 
     async def get_user(self, identifier: str) -> Optional[PersistedUser]:
         query = """
-        SELECT * FROM "User" 
+        SELECT * FROM "User"
         WHERE identifier = $1
         """
         result = await self.execute_query(query, {"identifier": identifier})
@@ -308,7 +299,7 @@ class ChainlitDataLayer(BaseDataLayer):
                     object_key=elements[0]["objectKey"]
                 )
         query = """
-        DELETE FROM "Element" 
+        DELETE FROM "Element"
         WHERE id = $1
         """
         params = {"id": element_id}
@@ -354,15 +345,15 @@ class ChainlitDataLayer(BaseDataLayer):
         ON CONFLICT (id) DO UPDATE SET
             "parentId" = COALESCE(EXCLUDED."parentId", "Step"."parentId"),
             input = COALESCE(EXCLUDED.input, "Step".input),
-            metadata = CASE 
-                WHEN EXCLUDED.metadata <> '{}' THEN EXCLUDED.metadata 
-                ELSE "Step".metadata 
+            metadata = CASE
+                WHEN EXCLUDED.metadata <> '{}' THEN EXCLUDED.metadata
+                ELSE "Step".metadata
             END,
             name = COALESCE(EXCLUDED.name, "Step".name),
             output = COALESCE(EXCLUDED.output, "Step".output),
-            type = CASE 
-                WHEN EXCLUDED.type = 'run' THEN "Step".type 
-                ELSE EXCLUDED.type 
+            type = CASE
+                WHEN EXCLUDED.type = 'run' THEN "Step".type
+                ELSE EXCLUDED.type
             END,
             "threadId" = COALESCE(EXCLUDED."threadId", "Step"."threadId"),
             "endTime" = COALESCE(EXCLUDED."endTime", "Step"."endTime"),
@@ -412,7 +403,7 @@ class ChainlitDataLayer(BaseDataLayer):
 
     async def get_thread_author(self, thread_id: str) -> str:
         query = """
-        SELECT u.identifier 
+        SELECT u.identifier
         FROM "Thread" t
         JOIN "User" u ON t."userId" = u.id
         WHERE t.id = $1
@@ -424,7 +415,7 @@ class ChainlitDataLayer(BaseDataLayer):
 
     async def delete_thread(self, thread_id: str):
         elements_query = """
-        SELECT * FROM "Element" 
+        SELECT * FROM "Element"
         WHERE "threadId" = $1
         """
         elements_results = await self.execute_query(
@@ -444,8 +435,8 @@ class ChainlitDataLayer(BaseDataLayer):
         self, pagination: Pagination, filters: ThreadFilter
     ) -> PaginatedResponse[ThreadDict]:
         query = """
-        SELECT 
-            t.*, 
+        SELECT
+            t.*,
             u.identifier as user_identifier,
             (SELECT COUNT(*) FROM "Thread" WHERE "userId" = t."userId") as total
         FROM "Thread" t
@@ -520,9 +511,9 @@ class ChainlitDataLayer(BaseDataLayer):
 
         # Get steps and related feedback
         steps_query = """
-        SELECT  s.*, 
-                f.id feedback_id, 
-                f.value feedback_value, 
+        SELECT  s.*,
+                f.id feedback_id,
+                f.value feedback_value,
                 f."comment" feedback_comment
         FROM "Step" s left join "Feedback" f on s.id = f."stepId"
         WHERE s."threadId" = $1
@@ -532,7 +523,7 @@ class ChainlitDataLayer(BaseDataLayer):
 
         # Get elements
         elements_query = """
-        SELECT * FROM "Element" 
+        SELECT * FROM "Element"
         WHERE "threadId" = $1
         """
         elements_results = await self.execute_query(
@@ -667,29 +658,14 @@ class ChainlitDataLayer(BaseDataLayer):
     async def cleanup(self):
         """Cleanup database connections"""
         if self.pool:
+            logger.debug("Cleaning up connection pool")
             await self.pool.close()
+            self.pool = None
 
-    def _sync_cleanup(self):
-        """Cleanup database connections in a synchronous context."""
-        if self.pool and not self.pool.is_closing():
-            loop = asyncio.get_event_loop()
-            if loop.is_running():
-                loop.create_task(self.cleanup())
-            else:
-                try:
-                    cleanup_loop = asyncio.new_event_loop()
-                    asyncio.set_event_loop(cleanup_loop)
-                    cleanup_loop.run_until_complete(self.cleanup())
-                    cleanup_loop.close()
-                except Exception as e:
-                    logger.error(f"Error during sync cleanup: {e}")
-
-    def _signal_handler(self, sig, frame):
-        """Handle signals for graceful shutdown."""
-        logger.info(f"Received signal {sig}, cleaning up connection pool.")
-        self._sync_cleanup()
-        # Re-raise the signal after cleanup
-        signal.default_int_handler(sig, frame)
+    async def close(self) -> None:
+        if self.storage_client:
+            await self.storage_client.close()
+        await self.cleanup()
 
 
 def truncate(text: Optional[str], max_length: int = 255) -> Optional[str]:
