@@ -173,7 +173,10 @@ async def connection_successful(sid):
     await context.emitter.clear("clear_ask")
     await context.emitter.clear("clear_call_fn")
 
-    if context.session.restored:
+    if context.session.restored and not context.session.has_first_interaction:
+        if config.code.on_chat_start:
+            task = asyncio.create_task(config.code.on_chat_start())
+            context.session.current_task = task
         return
 
     if context.session.thread_id_to_resume and config.code.on_chat_resume:
